<?php

namespace App\Helpers;

use Illuminate\Support\Facades\Cache;
use App\Models\DistAdminDistributor;

class SiteCache
{
    /**
     * 获取或缓存商店信息
     *
     * @param string|null $domain
     * @param int $seconds 缓存时间（秒）
     * @return Dist|null
     */
    public static function getDist(?string $domain = null, int $seconds = 600): ?string
    {
        if (is_null($domain)) {
            return null; // 如果未传入域名，返回 null
        }

        return Cache::tags([$domain, 'dist'])->remember("dist_{$domain}", $seconds, function () use ($domain) {
            $dist= DistAdminDistributor::where('custom_domain', $domain)
                ->orWhere('secondary_domain', $domain)
                ->first();
            //dd($dist);  // 调试缓存的数据
            // 序列化存储
            return serialize($dist);

        });
    }

    /**
     * 清除商店信息缓存
     *
     * @param string|null $domain
     * @return void
     */
    public static function clearDistCache(?string $domain = null): void
    {
        if (is_null($domain)) {
            return; // 如果未传入域名，不执行清除操作
        }

        Cache::tags([$domain, 'dist'])->forget("dist_{$domain}");
    }

    /**
     * 获取或缓存商品信息
     *
     * @param string|null $domain
     * @param int|null $productId
     * @param int $seconds 缓存时间（秒）
     * @return Product|null
     */
    public static function getProduct(?string $domain = null, ?int $productId = null, int $seconds = 600): ?Product
    {
        if (is_null($domain) || is_null($productId)) {
            return null; // 如果未传入 domain 或 productId，返回 null
        }

        return Cache::tags([$domain, 'product'])->remember("product_{$productId}", $seconds, function () use ($productId) {
            return Product::find($productId);
        });
    }

    /**
     * 清除商品信息缓存
     *
     * @param string|null $domain
     * @param int|null $productId
     * @return void
     */
    public static function clearProductCache(?string $domain = null, ?int $productId = null): void
    {
        if (is_null($domain) || is_null($productId)) {
            return; // 如果未传入 domain 或 productId，不执行清除操作
        }

        Cache::tags([$domain, 'product'])->forget("product_{$productId}");
    }

    /**
     * 获取或缓存文章信息
     *
     * @param string|null $domain
     * @param int|null $articleId
     * @param int $seconds 缓存时间（秒）
     * @return Article|null
     */
    public static function getArticle(?string $domain = null, ?int $articleId = null, int $seconds = 600): ?Article
    {
        if (is_null($domain) || is_null($articleId)) {
            return null; // 如果未传入 domain 或 articleId，返回 null
        }

        return Cache::tags([$domain, 'article'])->remember("article_{$articleId}", $seconds, function () use ($articleId) {
            return Article::find($articleId);
        });
    }

    /**
     * 清除文章信息缓存
     *
     * @param string|null $domain
     * @param int|null $articleId
     * @return void
     */
    public static function clearArticleCache(?string $domain = null, ?int $articleId = null): void
    {
        if (is_null($domain) || is_null($articleId)) {
            return; // 如果未传入 domain 或 articleId，不执行清除操作
        }

        Cache::tags([$domain, 'article'])->forget("article_{$articleId}");
    }

    /**
     * 清除某一域名下的所有缓存
     *
     * @param string $domain
     * @return void
     */
    public static function clearAllDomainCache(string $domain): void
    {
        Cache::tags([$domain])->flush(); // 清除该域名标签下的所有缓存
    }

    /**
     * 清除某一域名下特定类型的缓存
     *
     * @param string $domain
     * @param string $type
     * @return void
     */
    public static function clearSpecificTypeCache(string $domain, string $type): void
    {
        Cache::tags([$domain, $type])->flush(); // 清除该域名下特定类型的缓存
    }
}
